@@ -49,7 +49,7 @@ int main(int argc, char *argv[])
                          QStringLiteral(PROGRAM_VERSION), i18n("KAlarm autostart at login"),
                          KAboutLicense::GPL,
                          ki18n("Copyright 2001-%1, David Jarvie").subs(QStringLiteral("2020")).toString(), QString());
-    aboutData.addAuthor(i18n("David Jarvie"), i18n("Author"), QStringLiteral("djarvie@kde.org"));
+    aboutData.addAuthor(i18nc("@info:credit", "David Jarvie"), i18n("Author"), QStringLiteral("djarvie@kde.org"));
     aboutData.setOrganizationDomain("kalarm.kde.org");
     KAboutData::setApplicationData(aboutData);
 
