@@ -378,22 +378,14 @@ bool SpinBox2p::eventFilter(QObject* obj, QEvent* e)
             case QEvent::HoverEnter:
             {
                 auto* he = (QHoverEvent*)e;
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
                 QApplication::postEvent(mSpinbox2, new QHoverEvent(e->type(), QPoint(1, he->position().toPoint().y()), he->oldPos()));
-#else
-                QApplication::postEvent(mSpinbox2, new QHoverEvent(e->type(), QPoint(1, he->pos().y()), he->oldPos()));
-#endif
                 updateButtons = true;
                 break;
             }
             case QEvent::HoverLeave:
             {
                 auto* he = (QHoverEvent*)e;
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
                 QApplication::postEvent(mSpinbox2, new QHoverEvent(e->type(), he->position().toPoint(), QPoint(1, he->oldPos().y())));
-#else
-                QApplication::postEvent(mSpinbox2, new QHoverEvent(e->type(), he->pos(), QPoint(1, he->oldPos().y())));
-#endif
                 updateButtons = true;
                 break;
             }
@@ -839,7 +831,7 @@ bool SpinMirror::event(QEvent* e)
             if (mMainSpinbox->rect().contains(mMainSpinbox->mapFromGlobal(QCursor::pos())))
                 break;
             // fall through to QEvent::Enter
-            Q_FALLTHROUGH();
+            [[fallthrough]];
         case QEvent::Enter:
             QApplication::postEvent(mMainSpinbox, new QEvent(e->type()));
             break;
@@ -848,14 +840,10 @@ bool SpinMirror::event(QEvent* e)
             if (mMainSpinbox->rect().contains(mMainSpinbox->mapFromGlobal(QCursor::pos())))
                 break;
             // fall through to QEvent::HoverEnter
-            Q_FALLTHROUGH();
+            [[fallthrough]];
         case QEvent::HoverEnter:
             he = (QHoverEvent*)e;
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
             QApplication::postEvent(mMainSpinbox, new QHoverEvent(e->type(), he->position().toPoint(), he->oldPos()));
-#else
-            QApplication::postEvent(mMainSpinbox, new QHoverEvent(e->type(), he->pos(), he->oldPos()));
-#endif
             break;
         case QEvent::HoverMove:
             he = (QHoverEvent*)e;
@@ -869,11 +857,7 @@ bool SpinMirror::event(QEvent* e)
 
     if (he)
     {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
         QApplication::postEvent(mSpinbox, new QHoverEvent(e->type(), spinboxPoint(he->position()), spinboxPoint(he->oldPosF())));
-#else
-        QApplication::postEvent(mSpinbox, new QHoverEvent(e->type(), spinboxPoint(he->posF()), spinboxPoint(he->oldPosF())));
-#endif
         setButtonsImage();
     }
 
@@ -934,4 +918,7 @@ QRect spinBoxButtonsRect(const SpinBox* w, bool includeBorders)
 
 }
 
+#include "moc_spinbox2_p.cpp"
+#include "moc_spinbox2.cpp"
+
 // vim: et sw=4:
